package neo4j.repository.test;


import neo4j.model.test.Device;
import neo4j.relation.test.FeatureInfoGroupByDevice;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * @program: neo4j-demo
 * @description: 朋友关系
 * @author: Jamie.shi
 * @create: 2020-05-27 11:28
 **/
public interface DeviceRepository extends Neo4jRepository<Device, Long> {
    /**
     * 返回某系统下所有设备
     */
    @Query("MATCH p =(n:MetroSystem)-[r:SystemDevice]->(m:Device) WHERE n.name=$ name RETURN m")
    List<Device> findDevices(String name);

    /**
     * 根据名字查找
     */
    Device findByName(@Param("name") String name);

    /**
     * 查询满足 (设备)-[属性]-(设备属性)-[属性]-(设备) 关系的 设备
     */
    @Query("match (s:Device)-[:DeviceFeature]->(l:Feature)<-[:DeviceFeature]-(:Device) with l.name as featureName,collect(distinct s) as devices return featureName,devices")
    List<FeatureInfoGroupByDevice> findFeatureInfoGroupByDevice();

    /**
     * 查询满足 (设备)-[属性]-(设备属性)-[属性]-(设备) 关系的 设备
     */
    @Query("match (s:Device)-[:DeviceFeature]->(l:Feature)<-[:DeviceFeature]-(:Device) with l.name as featureName,collect(distinct s) as devices WHERE l.name=$ name return featureName,devices")
    List<FeatureInfoGroupByDevice> findFeatureInfoGroupByDeviceWithName(String name);
}
